#!/usr/bin/perl -w

####
#  FileWatch v0.08
# Copyright 2000 Lasse Kaislaniemi
# 
# See README.
####
#
# Edit stuff between CONFIG - EOC
#
### CONFIG ###
#
$prefix = '/filew';      ## WITHOUT '/' AT END
#
###  EOC   ###

use file_watch;

if(!defined($prefix)) {
    printf("
\$prefix has not been defined in file filew.pl. Please read README and
(re-)install FileWatch.
");
    exit;
}
$todo = shift;
if (!defined($todo)) { $todo = 'check'; }
@other_argvs = @ARGV;

$db = file_watch->new($prefix);
if ($db->loaddb() >= 0) {
    $db = $db->loaddb();
} else {
    $db->log_event ("Couldn't open database file.");
}
$db->configure();

if (defined(&$todo)) { 
    &$todo; 
} else {
    usage();
}
$db->savedb();
exit;

sub check {
    $db->check();
}

sub list {
    if (!defined($other_argvs[0])) {
        printf("FileWatch: list: nothing defined to be listed\n");
        usage();
	return;
    }
    if ($other_argvs[0] eq 'files') {
	my @lista = $db->list_files();
	foreach $cur (@lista) {
	    printf("$cur\n");
	}
    }

    return 0;
}

sub addscript {
    if (!defined($other_argvs[0])) {
        printf("FileWatch: addscript: no script number defined\n");
        usage();
        return;
    }

    if ($db->add_script($other_argvs[0], $other_argvs[1]) < 0) {
	printf("Error while adding script.\n");
    } else {
	printf("Script created.\n");
    }
    return 0;
}

sub showscript {
    if (!defined($other_argvs[0])) {
        printf("FileWatch: showscript: no script number defined\n");
        usage();
	return;
    }
    if ($other_argvs[0] =~ /^\d*$/) {
	if (!defined($db->{SCRIPTS}[$other_argvs[0]])) {
	    die "FileWatch: showscript: script number ".$other_argvs[0]." not defined.\n";
	}
	print "-- Script number ".$other_argvs[0]." --\n";
	print $db->{SCRIPTS}[$other_argvs[0]];
	print "\n-- EOF --\n\n";
    } else {
	die "FileWatch: showscript: script number not valid\n";
    }
}

sub delscript {
    if (!defined($other_argvs[0])) {
        printf("FileWatch: delscript: no script number defined\n");
        usage();
        return;
    }

    if ($db->del_script($other_argvs[0]) < 0) {
	printf("Error while deleting script.\n");
    } else {
	printf("Script deleted.\n");
    } 
    return 0;
}

sub del {
    if (!defined($other_argvs[0])) {
        printf("FileWatch: del: no file defined\n");
        usage();
        return;
    }
    if ($db->del_from_list($other_argvs[0]) == 0) {
	printf("File deleted from list.\n");
    } else {
	printf("File not deleted from list. (Not found in list?)\n");
    }
    $db->savedb();
    return;
}

sub add {
    if (!defined($other_argvs[0])) {
	printf("FileWatch: add: no file defined\n");
	usage();
	return;
    }
    $db->add_to_list($other_argvs[0]);
    $db->savedb();
    return;
}

sub usage {
    printf("
   -- FileWatch version ".$db->VERSION()." --
   Copyright 2000 Lasse Kaislaniemi

 This program is distributed under 
 GNU GPL License. See LICENSE for more.

- USAGE:
\tperl filew.pl [option] [attributes]

Please, read 'man filew' for more information.
");
}





